@@ -2,5 +2,5 @@ from django.apps import AppConfig
 
 
 class MailAuthAdmin(AppConfig):
-    name = 'mailauth.contrib.admin'
-    label = 'mailauth_admin'
+    name = "mailauth.contrib.admin"
+    label = "mailauth_admin"
