@@ -2,5 +2,5 @@ from django.apps import AppConfig
 
 
 class AuthConfig(AppConfig):
-    name = 'mailauth.contrib.user'
-    label = 'mailauth_user'
+    name = "mailauth.contrib.user"
+    label = "mailauth_user"
